package u8c.ui.mytest.action;

import java.util.ArrayList;
import java.util.List;
import nc.bs.framework.common.NCLocator;
import nc.itf.uap.IUAPQueryBS;
import nc.itf.uap.pf.IplatFormEntry;
import nc.jdbc.framework.processor.ColumnProcessor;
import nc.ui.hr.frame.FrameUI;
import nc.ui.hr.frame.action.AbstractAction;
import nc.ui.hr.frame.impl.MainBillMgrPanel;
import nc.ui.pub.beans.MessageDialog;
import nc.vo.hr.tools.pub.HRAggVO;
import nc.vo.pr.pray.PraybillHeaderVO;
import nc.vo.pr.pray.PraybillItemVO;
import nc.vo.pr.pray.PraybillVO;
import nc.vo.pub.BusinessException;
import nc.vo.pub.CircularlyAccessibleValueObject;
import nc.vo.pub.ValidationException;
import nc.vo.pub.lang.UFDate;
import u8c.bs.servlet.service.GetBaseDAOUtil;
import u8c.ui.mytest.panel.DemandMainPanel;
import u8c.ui.mytest.panel.DemandTestUI;
import u8c.vo.DemandBVO;
import u8c.vo.DemandVO;

public class AddPraybillAction extends AbstractAction {
	private IUAPQueryBS iuap = NCLocator.getInstance().lookup(IUAPQueryBS.class);
	DemandTestUI frameUI = null;

	public AddPraybillAction(FrameUI frameUI) {
		super(frameUI);
		this.frameUI = (DemandTestUI) frameUI;
	}

	@Override
	public void execute() throws Exception {
		DemandTestUI ui = (DemandTestUI) this.getFrameUI();
		MainBillMgrPanel mainMgrPanel = (MainBillMgrPanel) getMainPanel();
		int selectedRow = ((DemandMainPanel) getMainPanel()).getSelectedRow();
		HRAggVO s = (HRAggVO) mainMgrPanel.getMainBillCardPanel().getData();
		if (selectedRow == -1) {
			throw new ValidationException("请添加表体行");
		}
		if (null != s && s != null) {
			addPraybillVO(s);// 新增请购单
		}
	}

	
	/**
	 * 根据材料单生成请购单
	 * @param s
	 * @throws Exception 
	 */
	private void addPraybillVO(HRAggVO s) throws Exception {
		DemandVO demandVO = (DemandVO) s.getParentVO();//
		CircularlyAccessibleValueObject[] demandBVOList =  s.getChildrenVO();//
		List<DemandBVO> demandBVOs = new ArrayList();
		for(CircularlyAccessibleValueObject vo : demandBVOList) {
			if(vo instanceof DemandBVO) {
				demandBVOs.add((DemandBVO)vo);
			}
		}
		if(demandBVOs.size()==0) {
			throw new BusinessException("当前材料单没有数据，请先添加数据");
		}
		
		PraybillHeaderVO header = new PraybillHeaderVO();
		// 表头赋值
		header.setPk_corp(demandVO.getPk_corp());//公司
		header.setCoperator(demandVO.getBillmaker());//制单人
		header.setDpraydate(demandVO.getMakedate());//请购日期-->制单日期
		header.setIbillstatus(0);//单据状态
		header.setCpraypsn(demandVO.getWorkmanid());//请购人id-->业务员
		header.setCdeptid(demandVO.getPlandeptid());//请购部门id-->计划部门
		header.setVmemo(demandVO.getVnote());//备注
		header.setDr(0);
		header.setCaccountyear(String.valueOf(new UFDate().getYear()));//年份
		header.setIpraysource(5);//请购来源
		header.setIpraytype(2);//请购类型
		PraybillItemVO[] items = new PraybillItemVO[demandBVOs.size()];
		for (int i = 0; i < demandBVOs.size(); i++) {
			DemandBVO demandBVO = demandBVOs.get(i);
			PraybillItemVO praybillItemVO = new PraybillItemVO();
			praybillItemVO.setPk_corp(demandVO.getPk_corp()); // 公司
			// 表体赋值
			praybillItemVO.setCmangid(getCmangid(demandBVO.getCmaterialcode())); //存货编码
			praybillItemVO.setNpraynum(demandBVO.getNum()); //数量
			String cprojectid = "";//项目id
			if(demandBVO.getPrjcode().startsWith("1001")) {
				cprojectid = demandBVO.getPrjcode();
			}
			else {
				cprojectid = GetBaseDAOUtil.getprojectid(demandBVO.getPrjcode());
			}
			praybillItemVO.setCprojectid(cprojectid);
//			praybillItemVO.setCassistunit(demandBVO.getCastunitid());//辅助计量单位
//			praybillItemVO.setNassistnum(new UFDouble(demandBVO.getNastnum()));//辅计量数量
			praybillItemVO.setVproducenum(demandBVO.getVbatchcode());//批次号
			
			items[i] = praybillItemVO;
		}
		PraybillVO vo = new PraybillVO();
		vo.setParentVO(header);
		vo.setChildrenVO(items);

		// 新增请购单
		PraybillVO[] praybillVOs = new PraybillVO[1];
		praybillVOs[0] = vo;
		IplatFormEntry iIplatFormEntry = (IplatFormEntry)NCLocator.getInstance().lookup(IplatFormEntry.class.getName());
		ArrayList retObj = (ArrayList) iIplatFormEntry.processAction("SAVEBASE", "20", vo.getHeadVO().getDpraydate().toString(), null, vo, null, null);
		MessageDialog.showHintDlg(frameUI, "成功", "请购单"+retObj.get(5)+"新增成功");
//		IPrayBillMaintainAPI prayBillMaintainAPI = NCLocator.getInstance().lookup(IPrayBillMaintainAPI.class);
//		prayBillMaintainAPI.insert(praybillVOs);
	}

	/**
	 * 根据物料code查询主键
	 * @param code
	 * @return
	 * @throws BusinessException
	 */
	public String getCmangid(String code) throws BusinessException {
		String cmangid = null;
		String sql = " select pk_invbasdoc from bd_invbasdoc" + " where invcode  ='" + code + "' and dr =0 ";
		cmangid = (String) iuap.executeQuery(sql, new ColumnProcessor());
		if (cmangid == null) {
			throw new BusinessException("U8C物料code不存在:" + code);
		}
		return cmangid;
	}

}
